@@ -3,12 +3,14 @@ package Perl::Repository::APC;
 use strict;
 use warnings;
 
-my $Id = q$Id: APC.pm 15 2003-02-15 00:43:41Z k $;
-our $VERSION = sprintf "%.3f", 1 + substr(q$Rev: 15 $,4)/1000;
+my $Id = q$Id: APC.pm 18 2003-02-15 01:16:27Z k $;
+our $VERSION = sprintf "%.3f", 1 + substr(q$Rev: 18 $,4)/1000;
 
 sub new {
-  die sprintf "Not enough arguments for %s -> new ()\n", __PACKAGE__ unless @_ == 2;
-
+  unless (@_ == 2){
+    require Carp;
+    Carp::croak(sprintf "Not enough arguments for %s -> new ()\n", __PACKAGE__);
+  }
   my $proto   =  shift;
   my $class   =  ref $proto || $proto;
 
